#
# spec file for package mpfr
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mpfr
BuildRequires:  gmp-devel
Version:        3.1.2
Release:        11.53
Summary:        The GNU multiple-precision floating-point library
License:        LGPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://www.mpfr.org/
Source:         http://www.mpfr.org/mpfr-%{version}/mpfr-%{version}.tar.bz2
Source2:        baselibs.conf
Patch1:         mpfr-3.1.2-patch11.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The MPFR library is a C library for multiple-precision floating-point
computations with exact rounding (also called correct rounding). It is
based on the GMP multiple-precision library.

The main goal of MPFR is to provide a library for multiple-precision
floating-point computation which is both efficient and has a
well-defined semantics. It copies the good ideas from the ANSI/IEEE-754
standard for double-precision floating-point arithmetic (53-bit
mantissa).


%package -n libmpfr4
Summary:        The GNU multiple-precision floating-point shared library
Group:          Development/Libraries/C and C++

%description -n libmpfr4
The MPFR library is a C library for multiple-precision floating-point
computations with exact rounding (also called correct rounding). It is
based on the GMP multiple-precision library.


%package devel
Summary:        Development files for the GNU multiple-precision floating-point library
Group:          Development/Libraries/C and C++
Requires:       gmp-devel
Requires:       libmpfr4 = %{version}
PreReq:         %install_info_prereq

%description devel
Development files for the GNU multiple-precision floating-point library.

The MPFR library is a C library for multiple-precision floating-point
computations with exact rounding (also called correct rounding). It is
based on the GMP multiple-precision library.


%prep
%setup -q
%patch1 -p1

%build
%configure \
%ifarch %sparc hppa
	--disable-thread-safe \
%else
	--enable-thread-safe \
%endif
	--enable-shared \
	--docdir=%{_docdir}/mpfr
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%makeinstall
rm ${RPM_BUILD_ROOT}%{_libdir}/lib*.la

%post -n libmpfr4 -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun -n libmpfr4 -p /sbin/ldconfig

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -n libmpfr4
%defattr(-,root,root)
%{_libdir}/libmpfr.so.4*

%files devel
%defattr(-,root,root)
%doc %{_docdir}/mpfr
%doc %{_infodir}/mpfr.info.gz
%{_libdir}/libmpfr.a
%{_libdir}/libmpfr.so
%{_prefix}/include/mpf2mpfr.h
%{_prefix}/include/mpfr.h

%changelog
* Thu Jan  8 2015 rguenther@suse.com
- Add mpfr-3.1.2-patch11.diff to fix possible buffer overflow in
  mpfr_strtofr (CVE-2014-9474).  [bnc#911812]
* Tue Apr 16 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Mar 14 2013 rguenther@suse.com
- Update to version 3.1.2.
  * Bug fixes
  * Updated examples to the MPFR 3.x API
* Wed Jul  4 2012 rguenther@suse.com
- Update to version 3.1.1.
  * Bug fixes
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Tue Oct 11 2011 rguenther@suse.com
- Update to version 3.1.0.
  * The mpfr_urandom and mpfr_urandomb functions now return identical
    values on processors with different word size.
  * Speed improvement for the mpfr_sqr and mpfr_div functions using
    Mulders' algorithm.
  * Much faster formatted output (mpfr_printf, etc.) with %%Rg and similar.
  * New divide-by-zero exception (flag) and associated functions.
- Remove bogus provides/obsoletes for old shared library version.
- Fix license, it is LGPL v3 or later.
* Fri Apr  8 2011 rguenther@novell.com
- Update to version 3.0.1.
  * Minor bugfixes.
* Mon Sep  6 2010 rguenther@novell.com
- Update to version 3.0.0.
  * Bump SO version to 4.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon May 17 2010 adrian@suse.de
- PA-Risc is not threadsafe just as sparc
* Fri Dec 11 2009 jengelh@medozas.de
- add baselibs.conf to specfile as source
* Mon Dec  7 2009 jengelh@medozas.de
- Do not use --enable-thread-safe on SPARC (Fedora does the same) -
  the tests segfault if TS is enabled
* Mon Nov 30 2009 rguenther@suse.de
- Update to version 2.4.2.
  * Bug and documentation fixes.
* Wed Jul 22 2009 rguenther@suse.de
- Add x86 baselibs entry.
* Mon Mar 16 2009 rguenther@suse.de
- Update to version 2.4.1 (no changes).
- Apply current cummulative bugfixing patch.
  * mpfr_fmod, mpfr_remainder and mpfr_remquo rounding issues.
  * incorrect type in vasprintf.c.
  * wrong type in mpfr_zeta_ui.
* Wed Feb 25 2009 rguenther@suse.de
- Apply current cummulative bugfixing patch.
  * Fixes mpfr_snprintf and mpfr_vsnprintf buffer overflows.
* Tue Jan 27 2009 rguenther@suse.de
- Update to version 2.4.0.
  * Function mpfr_init_gmp_rand is no longer defined.
  * New functions:
  - between a MPFR number and a double: mpfr_add_d, mpfr_sub_d, mpfr_d_sub,
    mpfr_mul_d, mpfr_div_d, mpfr_d_div;
  - formatted input/output: mpfr_printf, mpfr_fprintf, mpfr_vprintf,
    mpfr_vfprintf, mpfr_sprintf, mpfr_snprintf, mpfr_vsprintf,
    mpfr_vsnprintf, mpfr_asprintf, mpfr_vasprintf;
  - mpfr_sinh_cosh, mpfr_li2, mpfr_modf, mpfr_fmod, mpfr_rec_sqrt.
  * Documented the fact that mpfr_random and mpfr_random2 will be suppressed
    in the next release, and that the specification of mpfr_eq may change in
    the next release (for compatibility with the mpf layer of GMP).
  * Bug fixes.
* Thu Nov 27 2008 ro@suse.de
- update baselibs.conf
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Sat Sep 13 2008 rguenther@suse.de
- Update to version 2.3.2.  Includes fixes for
  * Functions mpfr_pow_ui, mpfr_pow_si and mpfr_pow_z (but not mpfr_pow)
    on NaN^0 return NaN instead of 1.
  * Underflow bug in function mpfr_div.
  * Underflow bug due to double-rounding in functions mpfr_mul_2si,
    mpfr_div_2si and mpfr_div_2ui.
  * mpfr_exp problems.
  * The overflow flag can be lost in many functions called with the
    maximum exponent equal to MPFR_EMAX_MAX.
  * assertion/overflow/underflow issues with MPFR's power functions
    (mpfr_pow, mpfr_pow_ui, mpfr_pow_si, mpfr_pow_z).
  * Inifinite looping in mpfr_hypot.
  * Hide internal symbol mpfr_init_gmp_rand.
* Sat Aug  2 2008 rguenther@suse.de
- make mpfr-debuginfo depend on libmpfr1 instead of mpfr
* Tue Jul 15 2008 rguenther@suse.de
- allow build on SLES9 by disabling TLS usage there
* Tue Apr 29 2008 cthiel@suse.de
- obsolete mpfr-<arch> via baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 29 2008 rguenther@suse.de
- Update to final version 2.3.1.
  * Changes in the behavior of mpfr_strtofr and in its documentation
    concerning particular cases where the code and the documentation
    did not match.
  * Bug fixes; see <http://www.mpfr.org/mpfr-2.3.0/#bugs>.
  * Configure test for TLS support.
  * Improved MPFR manual.
* Sun Jan 13 2008 rguenther@suse.de
- Update to 2.3.1 release candidate 1.
  * Fixes various bugs.
* Wed Dec 12 2007 rguenther@suse.de
- Apply bugfixes from upstream, up to patch 4.  [#343720]
* Tue Oct  2 2007 ro@suse.de
- added provides mpfr to libmpfr1 package
* Wed Aug 29 2007 rguenther@suse.de
- New upstream version 2.3.0.
  * New functions mpfr_j0, mpfr_j1, mpfr_jn, mpfr_y0, mpfr_y1, mpfr_yn,
    mpfr_lgamma, mpfr_remainder, mpfr_remquo, mpfr_fms, mpfr_signbit,
    mpfr_setsign, mpfr_copysign, mpfr_get_patches.
  * Improved testsuite.
  * Bug fixes.
- Rename shared library package to libmfpr1 according to policy.
- Move AUTHORS and NEWS to mpfr-devel package.
- Package COPYING.LIB.
- Do not package CVS ChangeLog and README files.
* Wed Nov 29 2006 rguenther@suse.de
- New upstream version 2.2.1.
* Mon Oct  9 2006 rguenther@suse.de
- Apply bugfixes from upstream, up to patch 16.
* Wed Jun  7 2006 rguenther@suse.de
- Apply bugfixes from upstream, up to patch 12.
* Fri May 26 2006 rguenther@suse.de
- Fix the real bug, re-enable testsuite on s390.
* Fri May 26 2006 rguenther@suse.de
- Skip testsuite for s390.
* Mon May 15 2006 rguenther@suse.de
- Add provides to mpfr-devel to fix updating from gmp-devel.
* Sat May 13 2006 rguenther@suse.de
- New packages mpfr and mpfr-devel split from the gmp package as
  gmp no longer comes with the mpfr library included.  Version 2.2.0.
